Metrics
-------

Explainable metrics play a crucial role in achieving transparent and trustworthy outcomes of machine learning models. These metrics help in quantifying the ease of interpreting the results from explainability methods.


.. toctree::
   :maxdepth: 2

   metrics/spread
   metrics/similarity
   metrics/permutation
   metrics/stability